
##############################################
## Libraries
##############################################
library(CAMERA)
library(xlsx)
##############################################


##############################################
## Some settings
##############################################
settings=NULL
settings$general$ionmode = 1 # Ionization mode. 1 for pos and 2 for neg
settings$general$nSlaves = 1 # how many cores to use
##############################################



##############################################
## Load the filled and grouped xset
## This set has only a subset of the samples used in the paper; hence results might differ
##############################################
load('xset')
##############################################




##############################################
## CAMERA annotation
##############################################
# Select which rules to use
rules.jan <- read.xlsx(paste('rules_jan_',c('pos','neg')[settings$general$ionmode],'.xlsx',sep=""),1)

#Create an xsAnnotate object
xsa <- xsAnnotate(xset, nSlaves=settings$general$nSlaves, polarity = c('positive','negative')[settings$general$ionmode])

#Group after RT value of the xcms grouped peak
xsaF <- groupFWHM(xsa, perfwhm=1)

#Verify grouping
xsaC <- groupCorr(xsaF,graphMethod='lpc', pval=0.000001, calcCaS = T, cor_exp_th=0.7, cor_eic_th=0.7,calcCiS = T, calcIso = F)

#Annotate isotopes
xsaFI <- findIsotopes(xsaC, ppm=10, mzabs=0.01, intval="into")

#Annotate adducts and neutral losses
xsaFA <- findAdducts(xsaFI, polarity=c('positive','negative')[settings$general$ionmode], ppm=10, mzabs=0.01, multiplier=4, rules=rules.jan)


# Save the final annotated set
save(xsaFA,file='xsaFA_pos')
##############################################





##############################################
## Annotation rule statistics
##############################################
# Show all the rules and how often they were applied
View(cbind( as.character(rules.jan[,'name'])    ,    as.matrix(table(      factor(xsaFA@annoID[, "ruleID"], levels=1:max(xsaFA@annoID[, "ruleID"]))   ))  ))

# Barplot of how many times each rule was applied
barplot(rev(table(      factor(xsaFA@annoID[, "ruleID"], levels=1:88)   )),ylim=c(0,100),horiz=T,names.arg=rev(rules.jan[,'name']), las=2, cex.names=0.5)
##############################################
